diff --git a/src/app/DaemonReconnectWindow.qml b/src/app/DaemonReconnectWindow.qml
index 5a3fc864899718708d2e37c99390b4a3a57ebe87..e3feb37418c5007000fbb1693be4fa24eb646fea 100644
--- a/src/app/DaemonReconnectWindow.qml
+++ b/src/app/DaemonReconnectWindow.qml
@@ -85,7 +85,7 @@ ApplicationWindow {
                     Layout.alignment: Qt.AlignHCenter | Qt.AlignTop
                     Layout.topMargin: preferredMargin
 
-                    text: connectionFailed ? JamiStrings.reconnectWarn : JamiStrings.reconnectTry
+                    text: connectionFailed ? JamiStrings.reconnectWarn : JamiStrings.reconnectAttempt
                     font.pointSize: 11
                     horizontalAlignment: Text.AlignHCenter
                     verticalAlignment: Text.AlignVCenter
diff --git a/src/app/MainApplicationWindow.qml b/src/app/MainApplicationWindow.qml
index 67f5ac409bb2534cf05268f1fc4721ecaf2c2f5b..18ce79e4506830dab88808362c62c83f8e7d2513 100644
--- a/src/app/MainApplicationWindow.qml
+++ b/src/app/MainApplicationWindow.qml
@@ -362,7 +362,7 @@ ApplicationWindow {
 
         function onUpdateCheckReplyReceived(ok, found) {
             if (!ok) {
-                // Show an error dialog describing that we could not successfully check for an update.
+                // Show an error dialog describing that an update check failed.
                 presentUpdateInfoDialog(JamiStrings.updateCheckError);
                 return;
             }
diff --git a/src/app/ViewCoordinator.qml b/src/app/ViewCoordinator.qml
index 4bd71e7510d01793c8b6fdb6e5f21ebaca32f9c4..c978dafc5fa30f3e2fc746b8753e0d45a836c527 100644
--- a/src/app/ViewCoordinator.qml
+++ b/src/app/ViewCoordinator.qml
@@ -145,7 +145,7 @@ QtObject {
                 if (!view.managed)
                     view.presented();
             }, props)) {
-            print("could not create view:", viewName);
+            print("An error occurred while creating view:", viewName);
         }
     }
 
@@ -184,7 +184,7 @@ QtObject {
             } else
                 view = rootView.pop(StackView.Immediate);
             if (!view) {
-                print("could not pop view:", obj.objectName);
+                print("An error occurred while attempting to pop view:", obj.objectName);
                 resolveStack();
                 return;
             }
@@ -194,7 +194,7 @@ QtObject {
             if (view.managed) {
                 var objectName = view ? view.objectName : obj.objectName;
                 if (!viewManager.destroyView(resources[objectName])) {
-                    print("could not destroy view:", objectName);
+                    print("An error occurred while attempting to destroy view:", objectName);
                 } else {
                     print("destroyed view:", objectName);
                 }
diff --git a/src/app/dbuserrorhandler.cpp b/src/app/dbuserrorhandler.cpp
index 4c474aa235fc762f0def66295305c27722b028db..59b12c3c5b4bdf73e0cfa86705abf54b4d04a57b 100644
--- a/src/app/dbuserrorhandler.cpp
+++ b/src/app/dbuserrorhandler.cpp
@@ -29,13 +29,13 @@ void
 DBusErrorHandler::errorCallback()
 {
     qDebug() << "Dring has possibly crashed, "
-                "or has been killed... will wait 2.5 seconds and try to reconnect";
+                "or has been killed… will wait 2.5 seconds before attempting to reconnect.";
 
     Q_EMIT showDaemonReconnectPopup(true);
 
     QTimer::singleShot(2500, this, [this]() {
         if ((!lrc::api::Lrc::isConnected()) || (!lrc::api::Lrc::dbusIsValid())) {
-            qDebug() << "Could not reconnect to the daemon";
+            qDebug() << "An error occurred while attempting to reconnect to the daemon.";
             Q_EMIT daemonReconnectFailed();
         } else {
             static_cast<DBusErrorHandler&>(GlobalInstances::dBusErrorHandler())
diff --git a/src/app/mainview/components/ChatViewHeader.qml b/src/app/mainview/components/ChatViewHeader.qml
index 05c12cedf457bee3b45aef9681784cde3122d73b..43f7f8b3d00a56a9c1ba03e55fe3d3146676ddca 100644
--- a/src/app/mainview/components/ChatViewHeader.qml
+++ b/src/app/mainview/components/ChatViewHeader.qml
@@ -152,7 +152,7 @@ Rectangle {
             visible: interactionButtonsVisibility &&
                      (!addMemberVisibility || UtilsAdapter.getAppValue(Settings.EnableExperimentalSwarm))
             source: JamiResources.place_audiocall_24dp_svg
-            toolTipText: JamiStrings.placeAudioCall
+            toolTipText: JamiStrings.startAudioCall
 
             onClicked: CallAdapter.placeAudioOnlyCall()
         }
@@ -164,7 +164,7 @@ Rectangle {
                      CurrentAccount.videoEnabled_Video &&
                      (!addMemberVisibility || UtilsAdapter.getAppValue(Settings.EnableExperimentalSwarm))
             source: JamiResources.videocam_24dp_svg
-            toolTipText: JamiStrings.placeVideoCall
+            toolTipText: JamiStrings.startVideoCall
 
             onClicked: CallAdapter.placeCall()
         }
diff --git a/src/app/net/jami/Constants/JamiStrings.qml b/src/app/net/jami/Constants/JamiStrings.qml
index 6d7c3e6288ff6cf9dc0a5b548cb69923cbce835c..19befd42f481a1559563561bc450e90a01af8869 100644
--- a/src/app/net/jami/Constants/JamiStrings.qml
+++ b/src/app/net/jami/Constants/JamiStrings.qml
@@ -29,7 +29,7 @@ Item {
     property string accept: qsTr("Accept")
     property string acceptAudio: qsTr("Accept in audio")
     property string acceptVideo: qsTr("Accept in video")
-    property string refuse: qsTr("Refuse")
+    property string refuse: qsTr("Decline")
     property string endCall: qsTr("End call")
     property string incomingAudioCallFrom: qsTr("Incoming audio call from {}")
     property string incomingVideoCallFrom: qsTr("Incoming video call from {}")
@@ -40,8 +40,8 @@ Item {
     property string migrateConversation: qsTr("Migrate conversation")
 
     // DaemonReconnectWindow
-    property string reconnectWarn: qsTr("Could not re-connect to the Jami daemon (jamid).\nJami will now quit.")
-    property string reconnectTry: qsTr("Trying to reconnect to the Jami daemon (jamid)…")
+    property string reconnectWarn: qsTr("An error occurred while attempting to reconnect to the Jami daemon (jamid).\nJami will now quit.")
+    property string reconnectAttempt: qsTr("Attempting to reconnect to the Jami daemon (jamid)…")
 
     // AboutPopUp
     property string buildID: qsTr("Build ID")
@@ -338,8 +338,6 @@ Item {
 
     // Chatview header
     property string hideChat: qsTr("Hide chat")
-    property string placeAudioCall: qsTr("Start audio call")
-    property string placeVideoCall: qsTr("Start video call")
     property string showExtensions: qsTr("Show available extensions")
     property string addToConversations: qsTr("Add to conversations")
     property string backendError: qsTr("A backend system error occurred: %0")
@@ -416,11 +414,11 @@ Item {
     property string linkedOtherDevices: qsTr("Other linked devices")
 
     // CurrentAccountSettings && AdvancedSettings
-    property string backupSuccessful: qsTr("Backup successful")
+    property string backupSuccessful: qsTr("Backup completed successfully.")
     property string backupFailed: qsTr("An error occurred while backing up account.")
-    property string changePasswordSuccess: qsTr("Password changed successfully")
+    property string changePasswordSuccess: qsTr("Password changed successfully.")
     property string changePasswordFailed: qsTr("An error occurred while changing account password.")
-    property string setPasswordSuccess: qsTr("Password set successfully")
+    property string setPasswordSuccess: qsTr("Password set successfully.")
     property string setPasswordFailed: qsTr("An error occurred while setting account password.")
     property string changePassword: qsTr("Change password")
     property string setPassword: qsTr("Encrypt account")
diff --git a/src/app/networkmanager.cpp b/src/app/networkmanager.cpp
index 2957381aab010f0dda7d85f56419a36d0a49081f..6d87a74e86bbaaa3fe29a0eb2a69a54dbeb38030 100644
--- a/src/app/networkmanager.cpp
+++ b/src/app/networkmanager.cpp
@@ -159,7 +159,7 @@ NetworkManager::downloadFile(const QUrl& url,
     if (!file->open(QIODevice::WriteOnly)) {
         Q_EMIT errorOccurred(GetError::ACCESS_DENIED);
         files_.remove(uuid);
-        qWarning() << Q_FUNC_INFO << "Could not open file for writing";
+        qWarning() << Q_FUNC_INFO << "An error occurred while opening file for writing.";
         return 0;
     }
 
diff --git a/src/app/screencastportal.cpp b/src/app/screencastportal.cpp
index 07490395d463aa138c38a249d084af8a492a433b..b0edf404d56de61b0a1194310ae7a4df71df8600 100644
--- a/src/app/screencastportal.cpp
+++ b/src/app/screencastportal.cpp
@@ -454,7 +454,7 @@ ScreenCastPortal::getPipewireFd()
 
     g_main_loop_run(glib_main_loop);
     // The main loop will run until it's stopped by openPipewireRemote (if
-    // all DBus method calls were successfully), abort (in case of error) or
+    // all DBus method calls were successful), abort (in case of error) or
     // on_cancelled_callback (if a DBus request is cancelled).
     // In the latter two cases, pw_ctx->portal_error gets set to a nonzero value.
     if (portal_error)
@@ -512,9 +512,10 @@ ScreenCastPortal::~ScreenCastPortal()
     // file descriptor needs to be closed by the client.
     if (close(pipewireFd) != 0) {
         int err = errno;
-        qWarning() << "Error while attempting to close PipeWire file descriptor: errno =" << err;
+        qWarning() << "An error occurred while attempting to close PipeWire file descriptor: errno ="
+                   << err;
     } else {
-        qInfo() << "Successfully closed PipeWire file descriptor";
+        qInfo() << "PipeWire file descriptor closed successfully.";
     }
 #endif
 }
\ No newline at end of file
diff --git a/src/app/settingsview/components/PluginPreferencesView.qml b/src/app/settingsview/components/PluginPreferencesView.qml
index 737135da3c9064ec35af0e2d1404951486ab44fe..6fd0e6fe83623ed14202c562d4411abc718d01d2 100644
--- a/src/app/settingsview/components/PluginPreferencesView.qml
+++ b/src/app/settingsview/components/PluginPreferencesView.qml
@@ -287,7 +287,7 @@ Item {
                                         PluginModel.uninstallPlugin(PluginId);
                                         PluginListModel.removePlugin(index);
                                         PluginAdapter.getPluginsFromStore();
-                                        // could not call root from here
+                                        // Unable to call root from here
                                         settings.ListView.view.parent.closed();
                                     }],
                                     "buttonRoles": [DialogButtonBox.AcceptRole, DialogButtonBox.RejectRole]
diff --git a/src/app/systemtray.cpp b/src/app/systemtray.cpp
index bcb8ed947f53908f149f1ae23cbf7c8c359299d0..d9119ba37ad11fa5ebab6e3d0b770da7b0537044 100644
--- a/src/app/systemtray.cpp
+++ b/src/app/systemtray.cpp
@@ -168,7 +168,7 @@ SystemTray::hideNotification(const QString& id)
     // Close
     GError* error = nullptr;
     if (!notify_notification_close(notification->second.nn.get(), &error)) {
-        C_WARN << QString("could not close notification: %1").arg(error->message);
+        C_WARN << QString("An error occurred while closing notification: %1").arg(error->message);
         g_clear_error(&error);
         return false;
     }
diff --git a/src/app/utils.cpp b/src/app/utils.cpp
index 2291844b476ea1686c6986a1f18b49ff715afbcb..94686139e9670e58a0a1993d4afa0d87321e86b6 100644
--- a/src/app/utils.cpp
+++ b/src/app/utils.cpp
@@ -170,7 +170,8 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
 #endif
 
     if (desktopPath.isEmpty() || !(QFile::exists(desktopPath))) {
-        qDebug() << "Could not locate .desktop file at" << desktopPath;
+        qDebug() << "An error occurred while attempting to locate .desktop file at"
+                 << desktopPath;
         return false;
     }
 
@@ -197,7 +198,8 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
             if (QDir().mkdir(autoStartDir)) {
                 qDebug() << "Created autostart directory:" << autoStartDir;
             } else {
-                qWarning() << "Could not create autostart directory:" << autoStartDir;
+                qWarning() << "An error occurred while creating autostart directory:"
+                           << autoStartDir;
                 return false;
             }
         }
@@ -207,7 +209,7 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
     QFile srcFile(desktopPath);
     bool result = srcFile.link(desktopFile);
     qDebug() << desktopFile
-             << (result ? "-> " + desktopPath + " successfully created" : "could not be created");
+             << (result ? "-> " + desktopPath + " created successfully" : "unable to be created");
     return result;
 #endif
 }
@@ -265,7 +267,7 @@ Utils::DeleteStartupLink(const std::wstring& wstrAppName)
             QFile::remove(desktopFile);
             qDebug() << "Autostart disabled," << desktopFile << "removed";
         } catch (...) {
-            qDebug() << "Could not remove" << desktopFile;
+            qDebug() << "Unable to remove" << desktopFile;
         }
     } else {
         qDebug() << desktopFile << "does not exist";
diff --git a/src/app/utilsadapter.cpp b/src/app/utilsadapter.cpp
index e04e4088caef91bff49de4943eddd81954d8fc9b..378889eaa516cf7064917b54cf2308ee7fa9acff 100644
--- a/src/app/utilsadapter.cpp
+++ b/src/app/utilsadapter.cpp
@@ -893,7 +893,7 @@ UtilsAdapter::createDummyImage() const
         qInfo() << "Dummy image created" << QDir::tempPath() + "/dummy.png";
         return QDir::tempPath() + "/dummy.png";
     } else {
-        C_WARN << "Could not create dummy image";
+        C_WARN << "An error occurred while creating dummy image.";
         return "";
     }
 }
diff --git a/src/libclient/contactmodel.cpp b/src/libclient/contactmodel.cpp
index 87ad4f7fbcf4a7606bbd65aa9e0e329f0aef0db7..e3673d48467450d7ea4ac7a71b5a28317ea89e67 100644
--- a/src/libclient/contactmodel.cpp
+++ b/src/libclient/contactmodel.cpp
@@ -1222,7 +1222,7 @@ ContactModelPimpl::slotUserSearchEnded(const QString& accountId,
         updateTemporaryMessage("");
         break;
     case 3: /* ERROR */
-        updateTemporaryMessage("could not find contact matching search");
+        updateTemporaryMessage("Unable to find contact matching search");
         break;
     default:
         break;
diff --git a/src/libclient/database.cpp b/src/libclient/database.cpp
index 6c3c252b38eaa2074d1a4df1527fe3ed45f511a3..a0d8ebc8efbb79c57f31e5b20c32b97f31410989 100644
--- a/src/libclient/database.cpp
+++ b/src/libclient/database.cpp
@@ -104,7 +104,7 @@ Database::load()
     // open the database.
     if (not db_.open()) {
         std::stringstream ss;
-        ss << "cannot open database: " << connectionName_.toStdString();
+        ss << "Unable to open database: " << connectionName_.toStdString();
         throw std::runtime_error(ss.str());
     }
 
@@ -116,7 +116,7 @@ Database::load()
             QSqlDatabase::database(connectionName_).commit();
         } catch (QueryError& e) {
             QSqlDatabase::database(connectionName_).rollback();
-            throw std::runtime_error("Could not correctly create the database");
+            throw std::runtime_error("An error occurred while creating the database.");
         }
     } else {
         migrateIfNeeded();
@@ -184,7 +184,7 @@ Database::migrateIfNeeded()
         QSqlDatabase::database().commit();
     } catch (QueryError& e) {
         QSqlDatabase::database().rollback();
-        throw std::runtime_error("Could not correctly migrate the database");
+        throw std::runtime_error("An error occurred while migrating the database");
     }
 }
 
@@ -193,7 +193,7 @@ Database::migrateFromVersion(const QString& currentVersion)
 {
     // If we ever have a new version, we can migrate the database here.
     LC_WARN << "Database migration from version " << currentVersion << " to " << version_
-            << " not implemented";
+            << " not implemented.";
 }
 
 void
diff --git a/src/libclient/globalinstances.h b/src/libclient/globalinstances.h
index 12fa5e3dd961d57d1e7404b1b8dc1e2cbab7b942..b136e64deeebed3fdfee404d2ef582ba2eed4a38 100644
--- a/src/libclient/globalinstances.h
+++ b/src/libclient/globalinstances.h
@@ -80,7 +80,7 @@ setInterface(Ts... args)
         auto i = new I(args...);
         setInterfaceInternal(i);
     } catch (void* e) { // TODO define some kind of object for errors like this
-        qDebug() << "Interface could not be set";
+        qDebug() << "An error occurred while setting the interface.";
     }
 }
 
diff --git a/src/libclient/shmrenderer.cpp b/src/libclient/shmrenderer.cpp
index 27043cbec94dec8f3b6a3e5ce32755ded6ee7d5b..f95c48d009a77a209626adb57800fb9f1b0ce754 100644
--- a/src/libclient/shmrenderer.cpp
+++ b/src/libclient/shmrenderer.cpp
@@ -162,7 +162,7 @@ public:
 
         // map frame data
         if (!remapShm()) {
-            qDebug() << "Could not resize shared memory";
+            qDebug() << "An error occurred resizing shared memory.";
             return false;
         }
 
@@ -191,7 +191,7 @@ public:
             shmUnlock();
 
             if (::munmap(shmArea, shmAreaLen)) {
-                qDebug() << "Could not unmap shared area: " << strerror(errno);
+                qDebug() << "An error occurred unmapping shared area:" << strerror(errno);
                 return false;
             }
 
@@ -199,7 +199,7 @@ public:
                 = (SHMHeader*) ::mmap(nullptr, mapSize, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
 
             if (shmArea == MAP_FAILED) {
-                qDebug() << "Could not remap shared area: " << strerror(errno);
+                qDebug() << "An error occurred remapping shared area:" << strerror(errno);
                 return false;
             }
 
@@ -261,8 +261,9 @@ ShmRenderer::startShm()
     pimpl_->fd = ::shm_open(pimpl_->path.toLatin1(), O_RDWR, 0);
 
     if (pimpl_->fd < 0) {
-        qWarning() << "could not open shm area" << pimpl_->path
-                   << ", shm_open failed:" << strerror(errno);
+        qWarning() << "An error occurred opening shm area"
+                   << pimpl_->path << ", shm_open failed:"
+                   << strerror(errno);
         return false;
     }
 
@@ -272,7 +273,7 @@ ShmRenderer::startShm()
         = (SHMHeader*) ::mmap(nullptr, mapSize, PROT_READ | PROT_WRITE, MAP_SHARED, pimpl_->fd, 0);
 
     if (pimpl_->shmArea == MAP_FAILED) {
-        qWarning() << "Could not remap shared area";
+        qWarning() << "An error occurred while remapping shared area.";
         return false;
     }
diff --git a/src/app/videodevices.cpp b/src/app/videodevices.cpp
index f3003e43fcdc16db9cbb4e8b902f7300c47d5f1a..3364ac4a9e44503b3ad2bf4917786791edf81a62 100644
--- a/src/app/videodevices.cpp
+++ b/src/app/videodevices.cpp
@@ -241,7 +241,7 @@ VideoDevices::startDevice(const QString& id, bool force)
         return {};
     auto& avModel = lrcInstance_->avModel();
     if (avModel.hasRenderer(id)) {
         // If the device is already started AND we're NOT trying to
         // force a format change, we can do nothing and return the
         // renderer id.
         if (!force) {
@@ -263,7 +263,7 @@ VideoDevices::stopDevice(const QString& id)
     if (lrcInstance_->avModel().stopPreview(id)) {
         deviceOpen_ = false;
     } else {
-        C_DBG << "Failed to stop device" << id;
+        C_DBG << "An error occurred while attempting to stop device" << id;
     }
 }
 
@@ -364,7 +364,7 @@ VideoDevices::onVideoDeviceEvent()
     auto& avModel = lrcInstance_->avModel();
     QString callId = lrcInstance_->getCurrentCallId();
 
-    // Decide whether a device has plugged, unplugged, or nothing has changed.
+    // Decide whether a device has been plugged in, unplugged, or nothing has changed.
     auto deviceList = avModel.getDevices();
     auto currentDeviceListSize = deviceList.size();
     auto previousDeviceListSize = get_listSize();
@@ -241,7 +241,7 @@ VideoDevices::startDevice(const QString& id, bool force)
     auto& avModel = lrcInstance_->avModel();
     if (avModel.hasRenderer(id)) {
-        // If the device is already started AND we're NOT trying to
+        // If the device is already started AND we're NOT attempting to
         // force a format change, we can do nothing and return the
         // renderer id.